<?php
/**
 * List of files inclusion and functions
 *
 * Define global variables:
 * $themename : theme name information
 * $shortname : short name information
 * $poris_version : current theme version
 * 
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */

global $poris_version;

$poris_version = wp_get_theme()->Version;

// Include theme functions
require_once( get_template_directory() . '/functions/theme-functions/theme-widgets.php' ); // Load widgets
require_once( get_template_directory() . '/functions/theme-functions/theme-support.php' ); // Load theme support
require_once( get_template_directory() . '/functions/theme-functions/theme-functions.php' ); // Load custom functions
require_once( get_template_directory() . '/functions/theme-functions/theme-styles.php' ); // Load JavaScript, CSS & comment list layout
require_once( get_template_directory() . '/functions/class-tgm-plugin-activation.php' ); // Load TGM-Plugin-Activation



/**
 * After setup theme
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */
function poris_theme_init() {
	add_action( 'widgets_init', 'poris_register_sidebars' );
}
add_action( 'after_setup_theme', 'poris_theme_init' );


/**
 * Loads the Options Panel
 * 
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */

// Include Kirki Options Customizer
require_once( dirname( __FILE__ ) . '/functions/theme-functions/theme-options.php' );

/**
 * Required & recommended plugins
 * *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0.5
 */
function poris_required_plugins() {
	$plugins = array(
		array(
			'name'			=> 'Kirki Toolkit',
			'slug'			=> 'kirki',
			'required'		=> false,
		),
	);

	$string = array(
		'page_title'                      => esc_html__( 'Install Required Plugins', 'poris' ),
		'menu_title'                      => esc_html__( 'Install Plugins', 'poris' ),
		'installing'                      => esc_html__( 'Installing Plugin: %s', 'poris' ),
		'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'poris' ),
		'notice_can_install_required'     => _n_noop(
			'This theme requires the following plugin: %1$s.',
			'This theme requires the following plugins: %1$s.',
			'poris'
		),
		'notice_can_install_recommended'  => _n_noop(
			'This theme recommends the following plugin: %1$s.',
			'This theme recommends the following plugins: %1$s.',
			'poris'
		),
		'notice_cannot_install'           => _n_noop(
			'Sorry, but you do not have the correct permissions to install the %1$s plugin.',
			'Sorry, but you do not have the correct permissions to install the %1$s plugins.',
			'poris'
		),
		'notice_ask_to_update'            => _n_noop(
			'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.',
			'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.',
			'poris'
		),
		'notice_ask_to_update_maybe'      => _n_noop(
			'There is an update available for: %1$s.',
			'There are updates available for the following plugins: %1$s.',
			'poris'
		),
		'notice_cannot_update'            => _n_noop(
			'Sorry, but you do not have the correct permissions to update the %1$s plugin.',
			'Sorry, but you do not have the correct permissions to update the %1$s plugins.',
			'poris'
		),
		'notice_can_activate_required'    => _n_noop(
			'The following required plugin is currently inactive: %1$s.',
			'The following required plugins are currently inactive: %1$s.',
			'poris'
		),
		'notice_can_activate_recommended' => _n_noop(
			'The following recommended plugin is currently inactive: %1$s.',
			'The following recommended plugins are currently inactive: %1$s.',
			'poris'
		),
		'notice_cannot_activate'          => _n_noop(
			'Sorry, but you do not have the correct permissions to activate the %1$s plugin.',
			'Sorry, but you do not have the correct permissions to activate the %1$s plugins.',
			'poris'
		),
		'install_link'                    => _n_noop(
			'Begin installing plugin',
			'Begin installing plugins',
			'poris'
		),
		'update_link'                     => _n_noop(
			'Begin updating plugin',
			'Begin updating plugins',
			'poris'
		),
		'activate_link'                   => _n_noop(
			'Begin activating plugin',
			'Begin activating plugins',
			'poris'
		),
		'return'                          => esc_html__( 'Return to Required Plugins Installer', 'poris' ),
		'dashboard'                       => esc_html__( 'Return to the dashboard', 'poris' ),
		'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'poris' ),
		'activated_successfully'          => esc_html__( 'The following plugin was activated successfully:', 'poris' ),
		'plugin_already_active'           => esc_html__( 'No action taken. Plugin %1$s was already active.', 'poris' ),
		'plugin_needs_higher_version'     => esc_html__( 'Plugin not activated. A higher version of %s is needed for this theme. Please update the plugin.', 'poris' ),
		'complete'                        => esc_html__( 'All plugins installed and activated successfully. %1$s', 'poris' ),
		'dismiss'                         => esc_html__( 'Dismiss this notice', 'poris' ),
		'contact_admin'                   => esc_html__( 'Please contact the administrator of this site for help.', 'poris' )
	);

	$theme_text_domain = 'poris';

	$config = array(
		'id' => 'poris',
		'default_path' => '',
		'menu' => 'themes.php',
		'parent_slug' => 'themes.php',
		'menu' => 'install-plugins',
		'has_notices' => true,
		'dismissable'  => true,
 		'dismiss_msg'  => '',
		'is_automatic' => true,
		'message' => '',
		'strings' => $string
	);

	tgmpa($plugins, $config);
}
add_action('tgmpa_register', 'poris_required_plugins');