<?php
/**
 * Function to load comment list
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */
if ( ! function_exists( 'poris_comment_list' ) ) {
	function poris_comment_list($comment, $args, $depth) {
		global $post;
		$author_post_id = $post->post_author;
		$GLOBALS['comment'] = $comment;

		// Allowed html tags will be display
		$allowed_html = array(
			'a' => array( 'href' => array(), 'title' => array() ),
			'abbr' => array( 'title' => array() ),
			'acronym' => array( 'title' => array() ),
			'strong' => array(),
			'b' => array(),
			'blockquote' => array( 'cite' => array() ),
			'cite' => array(),
			'code' => array(),
			'del' => array( 'datetime' => array() ),
			'em' => array(),
			'i' => array(),
			'q' => array( 'cite' => array() ),
			'strike' => array(),
			'ul' => array(),
			'ol' => array(),
			'li' => array()
		);
		
		switch ( $comment->comment_type ) :
			case '' :
	?>
		<li id="comment-<?php comment_ID() ?>" <?php comment_class(); ?>>
			<div class="thumbnail"><a href="#"><?php echo get_avatar( $comment, 60 ); ?></a></div><!-- .comment-author -->
		
			<div class="comment-detail">
				<div class="author">
					<label class="author-name"><?php comment_author_link(); ?></label> <span>-</span><span><?php echo get_comment_date('M d, Y'); ?></span>
				</div>
				
				<?php if ($comment->comment_approved == '0') : ?>
					<p class="moderate"><?php esc_html_e('Your comment is now awaiting moderation before it will appear on this post.', 'poris');?></p>
				<?php endif; ?>
				<?php echo apply_filters('comment_text', wp_kses( get_comment_text(), $allowed_html ) );  ?>
				
				<div class="reply">
					<?php echo comment_reply_link(array('reply_text' => '<i class="fa fa-comment-o"></i> '. esc_html__('Reply', 'poris'), 'depth' => $depth, 'max_depth' => $args['max_depth'] ));  ?>	
					<span class="edit-link"><?php edit_comment_link('<i class="fa fa-edit"></i> '.esc_html__(' Edit Comment', 'poris'), '', ''); ?></span>
				</div><!-- .reply -->
			</div><!-- .comment-metadata --><!-- .comment-content -->

		</li><!-- #comment-## -->
	<?php
			break;
			case 'pingback'  :
			case 'trackback' :
	?>
				<li id="comment-<?php comment_ID() ?>" <?php comment_class(); ?>>
					<div class="comment-box clearfix">
						<div class="author">
							<a href="<?php comment_author_url()?>"><?php esc_html_e('Pingback', 'poris'); ?></a>
						</div>
						<div class="comment-body">
							<?php comment_author(); ?>
						</div>
						<div class="meta">
							<?php comment_date(); echo ' - '; comment_time(); ?>
							<span class="edit-link"><i class="fa fa-edit"></i><?php edit_comment_link(esc_html__(' Edit Comment', 'poris'), '', ''); ?></span>
						</div>
						<hr class="comment-line"/>
					</div>
				</li>	
	<?php
			break;
		endswitch;
	}
}


if ( ! function_exists( 'poris_comment_form_top' ) ) {
	function poris_comment_form_top() {
	?>
	<div class="comment-form-wrapper">
	<?php
	}
	add_action( 'comment_form_top', 'poris_comment_form_top' );

	function poris_comment_form_bottom() {
	?>
	</div>
	
	<?php
	}
}
add_action( 'comment_form', 'poris_comment_form_bottom', 1 );

/**
 * Add class on posts prev & next
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */
if ( ! function_exists( 'poris_next_posts_link_class' ) ) {
	function poris_next_posts_link_class() {
	    return 'class="next"';
	}
}
add_filter('next_posts_link_attributes', 'poris_next_posts_link_class');

if ( ! function_exists( 'previous_posts_link_class' ) ) {
	function previous_posts_link_class() {
	    return 'class="prev"';
	}
}
add_filter('previous_posts_link_attributes', 'previous_posts_link_class');

/**
 * Function to check if the post is sticky or not
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */
if ( ! function_exists( 'poris_check_sticky' ) ) {
	function poris_check_sticky() {
	?>
		<?php if ( is_sticky() ) : ?>
			<span class="sticky"><?php esc_html_e('Sticky', 'poris'); ?></span>
		<?php endif; ?>
	<?php	
	}
}

/**
 * Estimate post reading time
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */
if( !function_exists( 'poris_reading_time ') ) {
	function poris_reading_time() {
		global $post;    
		
		$text = get_post_field( 'post_content', $post->ID );
	    $words = str_word_count( esc_attr($text) );
		$min = floor( $words / 200 );
		
		if( $min == 0 ) {
			return esc_html__('1 min read', 'poris');
		}
		
		return $min . esc_html__(' min read', 'poris');
	}
}

/**
 * Function to display post meta
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */
if ( ! function_exists( 'poris_post_meta' ) ) {
	function poris_post_meta() {
?>
		<div class="meta">
		<?php if ( get_theme_mod( 'poris_display_post_author', true ) ) : ?>
			<span class="author"><?php esc_html_e('Posted by', 'poris'); ?> <?php the_author_posts_link(); ?></span>
		<?php endif; ?>
		<?php if ( get_theme_mod( 'poris_display_post_date', true ) ) : ?>
			<span class="date"><?php echo date_i18n( 'F j, Y', strtotime( get_the_date('Y-m-d'), false ) ); ?></span>
		<?php endif; ?>
		</div>
<?php
	}
}

/**
 * Change default excerpt more text
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */
if( !function_exists( 'poris_excerpt_more ') ) {
	function poris_excerpt_more( ) {
		return '...';
	}
}
add_filter( 'excerpt_more', 'poris_excerpt_more', 999 );

/**
 * Change default excerpt length
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */
if( !function_exists( 'poris_excerpt_length ') ) {
	function poris_excerpt_length( $length ) {
		return intval( get_theme_mod( 'poris_post_excerpt_length', '65' ) );
	}
}
add_filter( 'excerpt_length', 'poris_excerpt_length', 999 );

/**
 * Facebook Open Graph Generator
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */
if( ! function_exists('poris_open_graph') ) {
	function poris_open_graph() {
		global $post;
		
	    echo '<meta property="og:title" content="' . esc_attr( get_the_title() ) . '" />';
	    echo '<meta property="og:site_name" content="' . esc_html( get_bloginfo('name') ) . '" />';
        echo '<meta property="og:type" content="article" />';
        echo '<meta property="og:url" content="' . esc_url( get_permalink() ) . '" />';
        echo '<meta property="og:description" content="' . esc_attr( strip_tags( wp_trim_words( $post->post_content, 65, '' ) ) ) . '" />';
		
		if (has_post_thumbnail( get_the_ID() )) { // use featured image if there is one
	        $feat_image = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'large' );
	        echo '<meta property="og:image" content="' . esc_attr( $feat_image[0] ) . '" />';
		} else {
	        echo '<meta property="og:image" content="http://placehold.it/500x400&amp;text='. esc_html__('No Thumbnail', 'poris') .'" />';
		}
	}
}

/**
 * Facebook Version Remove Query String
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */
function poris_remove_script_version( $src ){
	$parts = explode( '?', $src );
	return $parts[0];
}
add_filter( 'script_loader_src', 'poris_remove_script_version', 15, 1 );
add_filter( 'style_loader_src', 'poris_remove_script_version', 15, 1 );