<?php
/**
 * Add the theme's styles.css
 */
function poris_option_scripts() {
    wp_enqueue_style( 'poris', get_stylesheet_uri(), array(), time() );
}
add_action( 'wp_enqueue_scripts', 'poris_option_scripts' );

if ( class_exists( 'kirki' ) ) {
    /**
     * Add sections
     */
    Kirki::add_section( 'poris_general', array(
        'title'          => esc_attr__( 'General Settings', 'poris' ),
        'priority'       => 1,
        'capability'     => 'edit_theme_options',
    ) );

    Kirki::add_section( 'poris_color', array(
        'title'          => esc_attr__( 'Color Settings', 'poris' ),
        'priority'       => 2,
        'capability'     => 'edit_theme_options',
    ) );

    Kirki::add_section( 'poris_typography', array(
        'title'          => esc_attr__( 'Typography Settings', 'poris' ),
        'priority'       => 1,
        'capability'     => 'edit_theme_options',
    ) );

    Kirki::add_section( 'poris_advertising', array(
        'title'          => esc_attr__( 'Advertising Settings', 'poris' ),
        'priority'       => 1,
        'capability'     => 'edit_theme_options',
    ) );
    
    /**
     * Add the configuration.
     * This way all the fields using the 'poris_option' ID
     * will inherit these options
     */
    Kirki::add_config( 'poris_option', array(
        'capability'    => 'edit_theme_options',
        'option_type'   => 'theme_mod',
    ) );

    /**
     * Add fields
     */

    // Start Section general
    Kirki::add_field( 'poris_option', array(
        'type'        => 'custom',
        'settings'    => 'poris_general_text',
        'label'       => esc_attr__( 'Post Settings', 'poris' ),
        'section'     => 'poris_general',
        'default'     => '<div style="padding: 10px;background-color: #ffffff; color: #555555;">Post common settings.</div>',
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'slider',
        'settings'    => 'poris_post_excerpt_length',
        'label'       => esc_attr__( 'Post Excerpt Length', 'poris' ),
        'section'     => 'poris_general',
        'default'     => '65',
        'priority'    => 10,
        'choices'      => array(
            'min'  => 40,
            'max'  => 65,
            'step' => 1,
        )
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'switch',
        'settings'    => 'poris_display_post_author',
        'label'       => esc_attr__( 'Display Post Author', 'poris' ),
        'description' => esc_attr__( 'Display post author in each post.', 'poris' ),
        'section'     => 'poris_general',
        'default'     => true,
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'switch',
        'settings'    => 'poris_display_post_date',
        'label'       => esc_attr__( 'Display Post Date', 'poris' ),
        'description' => esc_attr__( 'Display post date in each post.', 'poris' ),
        'section'     => 'poris_general',
        'default'     => true,
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'switch',
        'settings'    => 'poris_display_post_category',
        'label'       => esc_attr__( 'Display Post Category', 'poris' ),
        'description' => esc_attr__( 'Display post category in detail page.', 'poris' ),
        'section'     => 'poris_general',
        'default'     => true,
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'switch',
        'settings'    => 'poris_display_author_bio',
        'label'       => esc_attr__( 'Display Author Bio', 'poris' ),
        'description' => esc_attr__( 'Display author bio in detail page.', 'poris' ),
        'section'     => 'poris_general',
        'default'     => true,
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'switch',
        'settings'    => 'poris_display_related_posts',
        'label'       => esc_attr__( 'Display Related Posts', 'poris' ),
        'description' => esc_attr__( 'Display related posts in detail page.', 'poris' ),
        'section'     => 'poris_general',
        'default'     => true,
        'priority'    => 10,
    ) );

    // End Section general

        // Start Section Colors
    Kirki::add_field( 'poris_option', array(
        'type'        => 'custom',
        'settings'    => 'poris_main_colors',
        'label'       => esc_attr__( 'Main Settings', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '<div style="padding: 10px;background-color: #ffffff; color: #555555;">Main color settings.</div>',
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_main_link_color',
        'label'       => esc_attr__( 'Main Link Color Default', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#01579b',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => 'a, a:link',
                'property' => 'color',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_main_link_hover_color',
        'label'       => esc_attr__( 'Main Link Color Hover', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#ad1457',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => 'a:hover',
                'property' => 'color',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_main_background_color',
        'label'       => esc_attr__( 'Main Background Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#eaeaea',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => 'body, #main-wrapper',
                'property' => 'background',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_left_background_color',
        'label'       => esc_attr__( 'Main Content Background Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#ffffff',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => '#main-content .container',
                'property' => 'background',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'custom',
        'settings'    => 'poris_header_colors',
        'label'       => esc_attr__( 'Header Settings', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '<div style="padding: 10px;background-color: #ffffff; color: #555555;">Header color settings.</div>',
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_header_background_color',
        'label'       => esc_attr__( 'Header Background Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#ffffff',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => '#main-header',
                'property' => 'background',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_hover_menu_background_color',
        'label'       => esc_attr__( 'Main Menu Hover/Active Background Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#555555',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => '.site-navigation ul li a:hover, .site-navigation ul li.current-menu-item > a, .site-navigation ul li.current-menu-ancestor > a',
                'property' => 'background',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_menu_link_color',
        'label'       => esc_attr__( 'Main Menu Link Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#ffffff',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => 'section#header-nav nav.site-navigation ul li > a, section#header-nav .site-navigation ul li.current-menu-item > a,section#header-nav  .site-navigation ul li.current-menu-ancestor > a',
                'property' => 'color',
            ),
        ),
    ) );


    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_hover_menu_color',
        'label'       => esc_attr__( 'Main Menu Hover/Active Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#dddddd',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => 'section#header-nav nav.site-navigation ul li > a:hover, section#header-nav .site-navigation ul li.current-menu-item > a,section#header-nav  .site-navigation ul li.current-menu-ancestor > a',
                'property' => 'color',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_menu_background_color',
        'label'       => esc_attr__( 'Main Navigation Background Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#212121',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => '#header-nav',
                'property' => 'background',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'custom',
        'settings'    => 'poris_footer_colors',
        'label'       => esc_attr__( 'Footer Settings', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '<div style="padding: 10px;background-color: #ffffff; color: #555555;">Footer color settings.</div>',
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_footer_link_color',
        'label'       => esc_attr__( 'Footer Link Color Default', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#000000',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => '#footer span a',
                'property' => 'color',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_footer_link_hover_color',
        'label'       => esc_attr__( 'Footer Link Color Hover', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#ad1457',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => '#footer span a:hover',
                'property' => 'color',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'custom',
        'settings'    => 'poris_form_colors',
        'label'       => esc_attr__( 'Form Settings', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '<div style="padding: 10px;background-color: #ffffff; color: #555555;">Form color settings.</div>',
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_form_input_background_color',
        'label'       => esc_attr__( 'Form Input Background Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#ffffff',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => 'form input[type="text"], form input[type="password"], form input[type="email"], form input[type="url"], form textarea, form select, select, textarea#message',
                'property' => 'background',
            ),
        ),
    ) );


    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_form_input_text_color',
        'label'       => esc_attr__( 'Form Input Text Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#000000',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => 'textarea#message,input#s',
                'property' => 'color',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_form_button_background_color',
        'label'       => esc_attr__( 'Form Button Background Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#414141',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => 'form input[type="submit"], form button, input.button',
                'property' => 'background',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_form_button_text_color',
        'label'       => esc_attr__( 'Form Button Text Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#ffffff',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => 'form input[type="submit"], form button, input.button, input#submit, button',
                'property' => 'color',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'color',
        'settings'    => 'poris_form_button_text_hover_color',
        'label'       => esc_attr__( 'Form Button Text Hover Color', 'poris' ),
        'section'     => 'poris_color',
        'default'     => '#dddddd',
        'priority'    => 10,
        'output'      => array(
            array(
                'element'  => 'form input[type="submit"], form button:hover, input.button:hover, input#submit:hover, button:hover',
                'property' => 'color',
            ),
        ),
    ) );
    // End Section Colors

     // Start Section Typography
    Kirki::add_field( 'poris_option', array(
        'type'        => 'custom',
        'settings'    => 'poris_header_typo',
        'label'       => esc_attr__( 'Header Settings', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => '<div style="padding: 10px;background-color: #ffffff; color: #555555;">Header typography settings.</div>',
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_site_title_typo',
        'label'       => esc_attr__( 'Site Title Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Montserrat',
            'font-size'      => '35px',
            'variant'        => '700',
            'line-height'    => '40px',
            'letter-spacing' => '0px',
            'color'          => '#212121',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'color'          => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element' => '#main-header #main-logo h2.site-title a', 
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_site_desc_typo',
        'label'       => esc_attr__( 'Site Description Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Montserrat',
            'font-size'      => '14px',
            'variant'        => '400',
            'line-height'    => '14px',
            'letter-spacing' => '0px',
            'color'          => '#777777',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'color'          => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element' => '#main-header #main-logo h4.site-desc',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_main_nav_typo',
        'label'       => esc_attr__( 'Main Navigation Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Montserrat',
            'font-size'      => '12px',
            'variant'        => '400',
            'line-height'    => '12px',
            'letter-spacing' => '0px',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element' => 'section#header-nav nav.site-navigation ul li > a',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'custom',
        'settings'    => 'poris_main_typo',
        'label'       => esc_attr__( 'Main Settings', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => '<div style="padding: 10px;background-color: #ffffff; color: #555555;">Main typography settings.</div>',
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_post_title_typo',
        'label'       => esc_attr__( 'Post Title Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Montserrat',
            'font-size'      => '24px',
            'variant'        => '400',
            'line-height'    => '28px',
            'letter-spacing' => '0px',
            'color'          => '#000000',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'color'          => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element' => 'article.hentry h3.post-title a, article.hentry h1.post-title',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_category_meta_typo',
        'label'       => esc_attr__( 'Category Meta Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'italic' ),
            'font-family'    => 'Lora',
            'font-size'      => '17px',
            'variant'        => '400',
            'line-height'    => '28px',
            'letter-spacing' => '1px',
            'color'          => '#e65100',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'color'          => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element' => 'article.hentry .category a',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_post_meta_typo',
        'label'       => esc_attr__( 'Post Meta Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Montserrat',
            'font-size'      => '12px',
            'variant'        => '300',
            'line-height'    => '30px',
            'letter-spacing' => '0px',
            'color'          => '#bababa',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'color'          => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element' => '.meta',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_pharagraph_typo',
        'label'       => esc_attr__( 'Main Pharagraph Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Lato',
            'font-size'      => '18px',
            'variant'        => '400',
            'line-height'    => '30px',
            'color'          => '#666666',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'color'          => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element' => 'body',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_right_pharagraph_typo',
        'label'       => esc_attr__( 'Right Content Pharagraph Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Lato',
            'font-size'      => '14px',
            'variant'        => '400',
            'line-height'    => '24px',
            'color'          => '#666666',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'color'          => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element' => '#right-content',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'custom',
        'settings'    => 'poris_form_typo',
        'label'       => esc_attr__( 'Form Settings', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => '<div style="padding: 10px;background-color: #ffffff; color: #555555;">Form typography settings.</div>',
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_form_input_typo',
        'label'       => esc_attr__( 'Form Input Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Lato',
            'font-size'      => '14px',
            'variant'        => '400',
            'line-height'    => '14px',
            'color'          => '#666666',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'color'          => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element'  => 'form input[type="text"], form input[type="password"], form input[type="email"], form input[type="url"], form textarea, form select, select',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_button_typo',
        'label'       => esc_attr__( 'Form Button Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Montserrat',
            'font-size'      => '12px',
            'variant'        => '700',
            'color'          => '#ffffff',
            'line-height'    => '22px',
            'letter-spacing' => '0px',
            'text-transform' => 'uppercase',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element'  => 'form input[type="submit"], form button, a.button, input.button, button',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'custom',
        'settings'    => 'poris_widget_typo',
        'label'       => esc_attr__( 'Widget Settings', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => '<div style="padding: 10px;background-color: #ffffff; color: #555555;">Widget typography settings.</div>',
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_widget_title_typo',
        'label'       => esc_attr__( 'Widget Title Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Montserrat',
            'font-size'      => '14px',
            'variant'        => '400',
            'line-height'    => '18px',
            'letter-spacing' => '3px',
            'color'          => '#000000',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'color'          => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element'  => 'h4.widget-title',
            ),
        ),
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'custom',
        'settings'    => 'poris_footer_typo',
        'label'       => esc_attr__( 'Footer Settings', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => '<div style="padding: 10px;background-color: #ffffff; color: #555555;">Footer typography settings.</div>',
        'priority'    => 10,
    ) );

    Kirki::add_field( 'poris_option', array(
        'type'        => 'typography',
        'settings'    => 'poris_footer_text_typo',
        'label'       => esc_attr__( 'Footer Typography', 'poris' ),
        'section'     => 'poris_typography',
        'default'     => array(
            'font-style'     => array( 'normal' ),
            'font-family'    => 'Lato',
            'font-size'      => '14px',
            'variant'        => '400',
            'line-height'    => '28px',
            'letter-spacing' => '0px',
            'color'          => '#666666',
        ),
        'priority'    => 10,
        'choices'     => array(
            'font-style'     => true,
            'font-family'    => true,
            'font-size'      => true,
            'variant'        => true,
            'line-height'    => true,
            'letter-spacing' => true,
            'color'          => true,
            'units'          => array( 'px' ),
        ),
        'output' => array(
            array(
                'element'  => '#footer',
            ),
        ),
    ) );
    // End Section Typography
}
?>