<?php
/**
 * Recent Posts Widget
 *
 * @package WordPress
 * @subpackage Poris
 * @since Poris 1.0.0
 */

// Widgets
add_action( 'widgets_init', 'poris_recent_posts_widget' );

// Register our widget
function poris_recent_posts_widget() {
	register_widget( 'Poris_Recent_Posts' );
}

// Warrior Latest Video Widget
class Poris_Recent_Posts extends WP_Widget {

	//  Setting up the widget
	function Poris_Recent_Posts() {
		$widget_ops  = array( 'classname' => 'poris_recent_posts', 'description' => esc_html__('Warrior Recent Posts Widget', 'poris') );
		$control_ops = array( 'id_base' => 'poris_recent_posts' );

		parent::__construct( 'poris_recent_posts', esc_html__('Warrior Recent Posts', 'poris'), $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {
		
		extract( $args );

		$poris_recent_posts_title = apply_filters( 'widget_title', empty( $instance['poris_recent_posts_title'] ) ?  esc_html__( 'Recent Posts', 'poris' ) : $instance['poris_recent_posts_title'], $instance, $this->id_base );
		$poris_recent_posts_count  = !empty( $instance['poris_recent_posts_count'] ) ? absint( $instance['poris_recent_posts_count'] ) : 3;

		if ( !$poris_recent_posts_count )
 			$poris_recent_posts_count = 3;

		$args_recent_posts = array(
			'post_type' => 'post',
			'post_status' => 'publish',
			'ignore_sticky_posts' => 1,
			'posts_per_page' => absint( $poris_recent_posts_count )
		);

		$poris_recent_posts = new WP_Query();
		$poris_recent_posts->query($args_recent_posts);

		if ( $poris_recent_posts->have_posts() ) :
?>
        <?php echo $before_widget; ?>

		<div class="recent">
			<?php echo $before_title . $poris_recent_posts_title . $after_title; ?>
				<div class="wrapper recent">
					<?php while( $poris_recent_posts->have_posts() ) : $poris_recent_posts->the_post(); ?>
						<article class="recent-post">
							<div class="thumbnail">
							<?php
								// Get featured image
								if ( has_post_thumbnail() ) {
									echo '<a href="'. get_permalink() .'" title="'. get_the_title() .'" alt="'. get_the_title() .'">';
									the_post_thumbnail( 'poris-small-thumb-2', array( 'alt' => get_the_title(), 'title' => get_the_title() ) );
									echo '</a>';
								} else {
									echo '<a href="'. get_permalink() .'" title="'. get_the_title() .'" alt="'. get_the_title() .'">';
									echo '<img src="http://placehold.it/80x80/333333/&text=&nbsp;" title="'. get_the_title() .'" alt="'. get_the_title() .'"/>';
									echo '</a>';
								}
							?>
							</div>

							<div class="detail">
								<h3 class="post-title"><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php echo wp_trim_words( get_the_title(), 4, '...'); ?></a></h3>
								<div class="meta">
								<span class="date"><?php echo date_i18n( 'M j, Y', strtotime( date('Y-m-d'), false ) ); ?></span>
									<span class="comments"><a href="<?php the_permalink(); ?>"><?php comments_number( esc_html__('0 Comment', 'poris'), esc_html__('1 Comment', 'poris'), esc_html__('%', 'poris') ); ?></a></span>
								</div>
							</div>
						</article>
					<?php endwhile; ?>
				</div>
		</div>
		
		<?php echo $after_widget; ?>
<?php
		endif;
		wp_reset_postdata();
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['poris_recent_posts_title'] = strip_tags( $new_instance['poris_recent_posts_title'] );
		$instance['poris_recent_posts_count']  = (int) $new_instance['poris_recent_posts_count'];
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array('poris_recent_posts_title' => esc_html__('Recent Posts', 'poris'), 'poris_recent_posts_count' => '3' ) );
	?>
        <p>
            <label for="<?php echo $this->get_field_id( 'poris_recent_posts_title' ); ?>"><?php esc_html_e('Widget Title:', 'poris'); ?></label>
            <input type="text" id="<?php echo $this->get_field_id( 'poris_recent_posts_title' ); ?>" class="widefat" name="<?php echo $this->get_field_name( 'poris_recent_posts_title' ); ?>" value="<?php echo esc_attr( $instance['poris_recent_posts_title'] ); ?>" />
        </p>
	<?php
	}
}
?>